﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Navigation;
using Microsoft.Phone.Controls;
using Microsoft.Phone.Shell;
using ContosoTransit.WP8App.Resources;
using ContosoTransit.WP8App.Models;
using Microsoft.Phone.Tasks;
using Microsoft.Phone.Wallet;
using System.Windows.Media.Imaging;
using ContosoTransit.WP8Library;

namespace ContosoTransit.WP8App
{
    public partial class MainPage : PhoneApplicationPage
    {        
        public MainPage()
        {
            InitializeComponent();

            service = new MockTransitService();

            addTask = new AddWalletItemTask();
            addTask.Completed +=task_Completed;
        }

        MockTransitService service;
        WalletTransactionItem walletCard;
        AddWalletItemTask addTask;

        protected override void OnNavigatedTo(NavigationEventArgs e)
        {
            String launchArgs;
            if (NavigationContext.QueryString.TryGetValue("ms_nfp_launchargs", out launchArgs))
            {
                if (launchArgs.Contains("stationid="))
                {
                    string stationId = launchArgs.Substring(launchArgs.IndexOf("stationid=") + 10);
                   
                    NavigationService.Navigate(new Uri("/StationPage.xaml?checkin=true&stationid=" +
                            stationId, UriKind.Relative));
                    NavigationService.RemoveBackEntry();
                }
            }
            
            walletCard = Wallet.FindItem("LoyaltyCard") as WalletTransactionItem;
            if (walletCard != null)
            {
                balanceTxt.Text = walletCard.DisplayBalance;
            }

            this.DataContext = service.GetStations();
        }

        private void stationLst_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            if (stationLst.SelectedItem == null)
                return;

            NavigationService.Navigate(new Uri("/StationPage.xaml?stationid=" + 
                (stationLst.SelectedItem as StationModel).Id, UriKind.Relative));

            stationLst.SelectedItem = null;
        }

        private void Loyalty_MouseLeftButtonUp(object sender, System.Windows.Input.MouseButtonEventArgs e)
        {
            if (walletCard == null)
            {
                AddCardToWallet();
            }
            else
            {
                NavigationService.Navigate(new Uri("/CardPage.xaml", UriKind.Relative));
            }
        }

        private void AddCardToWallet()
        {
            LoyaltyCardModel loyaltyCard = service.GetLoyaltyCard("123456");

            WalletTransactionItem item = new WalletTransactionItem("LoyaltyCard");
            item.CustomerName = loyaltyCard.Name;
            item.AccountNumber = loyaltyCard.UserId;
            item.DisplayName = "Contoso Transit";
            item.IssuerName = "Contoso Transit";
            item.IssuerPhone.Business = "888-555-1212";
            item.IssuerWebsite = new Uri("http://microsoft.com");
            item.DisplayBalance = loyaltyCard.PointBalance + " points";

            BitmapImage img = new BitmapImage();
            Uri logoUri = new Uri("Assets/contoso_transit_logo.png", UriKind.Relative);
            img.SetSource(Application.GetResourceStream(logoUri).Stream);
            item.Logo99x99 = img;
            item.Logo159x159 = img;
            item.Logo336x336 = img;

            item.NavigationUri = new Uri("/CardPage.xaml", UriKind.Relative);

            addTask.Item = item;
            addTask.Show();
        }

        void task_Completed(object sender, AddWalletItemResult e)
        {
            if (e.TaskResult == TaskResult.OK)
            {
                walletCard = e.Item as WalletTransactionItem;
                balanceTxt.Text = walletCard.DisplayBalance;

                NavigationService.Navigate(new Uri("/CardPage.xaml", UriKind.Relative));
            }
            
        }

        private void TagWriter_MouseLeftButtonUp(object sender, System.Windows.Input.MouseButtonEventArgs e)
        {
            NavigationService.Navigate(new Uri("/WriteTagPage.xaml", UriKind.Relative));
        }
        
    }
}