﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Navigation;
using Microsoft.Phone.Controls;
using Microsoft.Phone.Shell;
using ContosoTransit.WP8App.Models;
using Microsoft.Phone.Wallet;
using System.Text.RegularExpressions;
using System.Threading.Tasks;
using ContosoTransit.WP8Library;
using System.Windows.Media.Imaging;

namespace ContosoTransit.WP8App
{
    public partial class StationPage : PhoneApplicationPage
    {
        public StationPage()
        {
            InitializeComponent();
            service = new MockTransitService();
        }

        WalletTransactionItem  walletCard;
        MockTransitService service;
        StationModel station;


        protected override async void OnNavigatedTo(NavigationEventArgs e)
        {
            walletCard = Wallet.FindItem("LoyaltyCard") as WalletTransactionItem;

            if (walletCard == null)
                checkinBtn.Visibility = Visibility.Collapsed;
            else
                checkinBtn.Visibility = Visibility.Visible;

            string value = "";
            if (NavigationContext.QueryString.TryGetValue("stationid", out value))
            {
                int id = Convert.ToInt32(value);
                
                station = service.GetStations().Where(s => s.Id == id).SingleOrDefault();

                string autoCheckin;
                if (NavigationContext.QueryString.TryGetValue("checkin", out autoCheckin))
                {
                    if (autoCheckin == "true" && walletCard != null)
                    {
                        await LoyaltyCardCheckIn();
                    }
                }

                this.DataContext = station;
            }

        }

        private async void checkinBtn_Click(object sender, RoutedEventArgs e)
        {
            if (walletCard != null)
            {
                await LoyaltyCardCheckIn();
            }
        }

        private async Task LoyaltyCardCheckIn()
        {
            await UpdateLoyaltyCard(station.Id);

            MessageBox.Show("Check in complete. Balance is " + walletCard.DisplayBalance);

            checkinBtn.Visibility = Visibility.Collapsed;
        }
       

        private async Task UpdateLoyaltyCard(int stationId)
        {            
            int balance = service.UpdatePointsOnCheckIn(walletCard.AccountNumber, stationId);

            walletCard.DisplayBalance = balance + " points";

            DealModel deal = service.GetDealForStationCheckIn(stationId);
            if (deal != null)
            {
                string prompt = String.Format("A deal is available for {0} from {1}.  Add to wallet?",
                    deal.Name, deal.Issuer);
                MessageBoxResult result = MessageBox.Show(prompt, "Coupon available", MessageBoxButton.OKCancel);
                if (result == MessageBoxResult.OK)
                {
                    await AddDealToWallet(deal);
                }
            }

            await walletCard.SaveAsync();
        }

        private static async Task AddDealToWallet(DealModel model)
        {
            Deal deal = new Deal();
            deal.DisplayName = model.Name;
            deal.IssuerName = model.Issuer;
            deal.StartDate = DateTime.Now;
            deal.ExpirationDate = DateTime.Now.AddDays(model.DaysValid);
            deal.IsUsed = false;
            deal.Code = model.Code;
            deal.MerchantName = model.Issuer;
            deal.MerchantPhone.Business = model.MerchantPhone;

            BitmapImage logoImg = new BitmapImage();
            Uri logoUri = new Uri(model.LogoImagePath, UriKind.Relative);
            logoImg.SetSource(Application.GetResourceStream(logoUri).Stream);
            deal.Logo99x99 = logoImg;
            deal.Logo159x159 = logoImg;
            deal.Logo336x336 = logoImg;
            
            BitmapImage qrImg = new BitmapImage();
            Uri qrUri = new Uri(model.QRImagePath, UriKind.Relative);
            qrImg.SetSource(Application.GetResourceStream(qrUri).Stream);
            deal.BarcodeImage = qrImg;

            await deal.SaveAsync();
        }
    }
}