﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Navigation;
using Microsoft.Phone.Controls;
using Microsoft.Phone.Shell;
using ContosoTransit.WP8App.Models;
using Windows.Networking.Proximity;
using Windows.Storage.Streams;
using NdefLibrary.Ndef;
using System.Runtime.InteropServices.WindowsRuntime;
using ContosoTransit.WP8Library;

namespace ContosoTransit.WP8App
{
    public partial class WriteTagPage : PhoneApplicationPage
    {
        public WriteTagPage()
        {
            InitializeComponent();

            device = ProximityDevice.GetDefault();
            service = new MockTransitService();
        }

        MockTransitService service;
        ProximityDevice device;
        StationModel station;
       
        protected override void OnNavigatedTo(NavigationEventArgs e)
        {
            this.DataContext = service.GetStations();
        }

        private void writeBtn_Click(object sender, RoutedEventArgs e)
        {
            station = stationLst.SelectedItem as StationModel;
            if (station != null)
            {
                if (device != null)
                {
                    writeBtn.Visibility = System.Windows.Visibility.Collapsed;
                    device.SubscribeForMessage("WriteableTag", TagLocated);

                    statusTxt.Text = "Tap tag you wish to write";
                }
                else
                {
                    MessageBox.Show("Unable to initialize NFC hardware");
                }
            }
            else
            {
                MessageBox.Show("Please select a station for the tag info");
            }
        }

        private void TagLocated(ProximityDevice sender, ProximityMessage message)
        {
            device.StopSubscribingForMessage(message.SubscriptionId);

            string appId = Windows.ApplicationModel.Store.CurrentApp.AppId.ToString();
            string stationArgs = "stationid=" + station.Id;

            NdefLaunchAppRecord launchAppRecord = new NdefLibrary.Ndef.NdefLaunchAppRecord();
            launchAppRecord.Arguments = stationArgs;
            launchAppRecord.AddPlatformAppId("WindowsPhone", "{" + appId + "}");

            NdefMessage msg = new NdefMessage { launchAppRecord };

            device.PublishBinaryMessage("NDEF:WriteTag", msg.ToByteArray().AsBuffer(),
                TagWritten);

        }

        private void TagWritten(ProximityDevice sender, long messageId)
        {
            device.StopPublishingMessage(messageId);

            Dispatcher.BeginInvoke(() =>
            {
                MessageBox.Show("Tag written for " + station.Name);
                statusTxt.Text = "";
                writeBtn.Visibility = Visibility.Visible;

            });
        }

    }
}