﻿using System.Diagnostics;
using System.Windows;
using Microsoft.Phone.Scheduler;
using ContosoTransit.WP8Library;
using Microsoft.Phone.Wallet;
using System;

namespace ContosoTransit.WP8WalletAgent
{
    public class ContosoTransitWalletAgent : WalletAgent
    {
        /// <remarks>
        /// ScheduledAgent constructor, initializes the UnhandledException handler
        /// </remarks>
        static ContosoTransitWalletAgent()
        {
            // Subscribe to the managed exception handler
            Deployment.Current.Dispatcher.BeginInvoke(delegate
            {
                Application.Current.UnhandledException += UnhandledException;
            });
        }

        /// Code to execute on Unhandled Exceptions
        private static void UnhandledException(object sender, ApplicationUnhandledExceptionEventArgs e)
        {
            if (Debugger.IsAttached)
            {
                // An unhandled exception has occurred; break into the debugger
                Debugger.Break();
            }
        }

        /// <summary>
        /// Agent that runs a scheduled task
        /// </summary>
        /// <param name="task">
        /// The invoked task
        /// </param>
        /// <remarks>
        /// This method is called when a periodic or resource intensive task is invoked
        /// </remarks>
        protected override async void OnRefreshData(RefreshDataEventArgs args)
        {
            MockTransitService service = new MockTransitService();

            foreach (WalletItem item in args.Items)
            {
                WalletTransactionItem walletCard = item as WalletTransactionItem;
                if (walletCard != null)
                {
                    LoyaltyCardModel loyaltyCard = service.GetLoyaltyCard(walletCard.AccountNumber);
                    if (loyaltyCard != null)
                    {
                        foreach (var scan in loyaltyCard.StationsScanned.Keys)
                        {
                            if (!walletCard.TransactionHistory.ContainsKey(scan.ToString()))
                            {
                                StationModel station = loyaltyCard.StationsScanned[scan];
                                WalletTransaction txn = new WalletTransaction();
                                txn.TransactionDate = DateTime.Now;
                                txn.Description = station.Name;
                                txn.DisplayAmount = station.Points + " points";
                                walletCard.TransactionHistory.Add(DateTime.Now.ToString(), txn);
                            }
                        }
                    }
                    await walletCard.SaveAsync();
                }
            }
            NotifyComplete();
        }
    }
}